@@ -12,10 +12,14 @@ impl super::Node for Node {
         base_refs.append(&mut number_refs);
         (Box::new(Self { base, number }), base_refs)
     }
-    fn calc(&self, calculated_table: &Vec<Vec<Value>>) -> Value {
-        let base = self.base.calc(calculated_table);
-        let number = self.number.calc(calculated_table);
-        match (base, number) {
+    fn calc(
+        &mut self,
+        calculated_table: &Vec<Vec<Value>>,
+    ) -> (Value, Vec<(usize, usize)>, Vec<(usize, usize)>) {
+        let mut base = self.base.calc(calculated_table);
+        let mut number = self.number.calc(calculated_table);
+
+        let value = match (base.0, number.0) {
             (Value::Integer(base), Value::Integer(number)) => {
                 Value::Float((number as f64).log(base as f64))
             }
@@ -23,6 +27,10 @@ impl super::Node for Node {
             (Value::Float(base), Value::Integer(number)) => Value::Float((number as f64).log(base)),
             (Value::Float(base), Value::Float(number)) => Value::Float(number.log(base)),
             _ => Value::Error,
-        }
+        };
+
+        base.1.append(&mut number.1);
+        base.2.append(&mut number.2);
+        (value, base.1, base.2)
     }
 }
